==> pcl_1.10.0+dfsg.orig.tar.xz: pcl-pcl-1.10.0/apps/modeler/src/abstract_item.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Point Cloud Library (PCL) - www.pointclouds.org
 *  Copyright (c) 2012, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Willow Garage, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <pcl/apps/modeler/abstract_item.h>

#include <pcl/apps/modeler/main_window.h>
#include <pcl/apps/modeler/parameter_dialog.h>


//////////////////////////////////////////////////////////////////////////////////////////////
pcl::modeler::AbstractItem::AbstractItem()
{

}

//////////////////////////////////////////////////////////////////////////////////////////////
pcl::modeler::AbstractItem::~AbstractItem()
{

}

//////////////////////////////////////////////////////////////////////////////////////////////
void
pcl::modeler::AbstractItem::showContextMenu(const QPoint* position)
{
  QMenu menu(&MainWindow::getInstance());
  prepareContextMenu(&menu);
  menu.exec(*position);

  return;
}

//////////////////////////////////////////////////////////////////////////////////////////////
Ui::MainWindow*
pcl::modeler::AbstractItem::ui() const
{
  return MainWindow::getInstance().ui_;
}

//////////////////////////////////////////////////////////////////////////////////////////////
void
pcl::modeler::AbstractItem::showPropertyEditor()
{
  ParameterDialog* parameter_dialog = new ParameterDialog(getItemName() + " Properties", &MainWindow::getInstance());
  prepareProperties(parameter_dialog);

  if (parameter_dialog->exec() == QDialog::Accepted)
    setProperties();

  parameter_dialog->deleteLater();
}

==> pcl_1.12.1+dfsg.orig.tar.xz: pcl-pcl-1.12.1/apps/modeler/src/abstract_item.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Point Cloud Library (PCL) - www.pointclouds.org
 *  Copyright (c) 2012, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Willow Garage, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <pcl/apps/modeler/abstract_item.h>
#include <pcl/apps/modeler/main_window.h>
#include <pcl/apps/modeler/parameter_dialog.h>

//////////////////////////////////////////////////////////////////////////////////////////////
pcl::modeler::AbstractItem::AbstractItem() {}

//////////////////////////////////////////////////////////////////////////////////////////////
pcl::modeler::AbstractItem::~AbstractItem() {}

//////////////////////////////////////////////////////////////////////////////////////////////
void
pcl::modeler::AbstractItem::showContextMenu(const QPoint* position)
{
  QMenu menu(&MainWindow::getInstance());
  prepareContextMenu(&menu);
  menu.exec(*position);
}

//////////////////////////////////////////////////////////////////////////////////////////////
Ui::MainWindow*
pcl::modeler::AbstractItem::ui() const
{
  return MainWindow::getInstance().ui_;
}

//////////////////////////////////////////////////////////////////////////////////////////////
void
pcl::modeler::AbstractItem::showPropertyEditor()
{
  ParameterDialog* parameter_dialog =
      new ParameterDialog(getItemName() + " Properties", &MainWindow::getInstance());
  prepareProperties(parameter_dialog);

  if (parameter_dialog->exec() == QDialog::Accepted)
    setProperties();

  parameter_dialog->deleteLater();
}
